@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2017, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2018, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -181,6 +181,7 @@ if os.name == 'posix':
                     '/opt/local/include/db%d%s' %(major, bitness),
                     '/opt/sfw/include/db%d%s' %(major, bitness),
                     '/sw/include/db%d%s' %(major, bitness),
+                    '/usr/local/opt/berkeley-db@%s/include' % (major),
                     ])
 
             db_inc_paths.append('/usr/include/db%d%d%s' % \
@@ -206,7 +207,9 @@ if os.name == 'posix':
                 '/lib', '/usr/lib',
                 '/usr/lib/x86_64-linux-gnu/',
             ]
-            inc_dirs = compiler.include_dirs + ['/usr/include']
+            inc_dirs = compiler.include_dirs + [
+                '/usr/include', '/usr/local/opt/berkeley-db/include',
+            ]
 
             # See whether there is a Oracle or Sleepycat header in the standard
             # search path.
@@ -459,21 +462,23 @@ if sys.version_info[0] > 2 :
     version_suffix = "3"
 
 
+# #############################
+
 # Delete pkgsrc stale info
 # This is something that eventually should be not necesary.
 # XXX - jcea@jcea.es - 20170125
 from distutils import sysconfig
-def get_config_vars(*args):
-    if sysconfig._config_vars is None:
-        get_config_vars.original()
-        for k, v in list(sysconfig._config_vars.items()):
-            if not isinstance(v, str):
-                continue
-            j = ' '.join([i for i in v.split() if not i.endswith('/db4')])
-            sysconfig._config_vars[k] = j
-    return get_config_vars.original(*args)
-get_config_vars.original = sysconfig.get_config_vars
-sysconfig.get_config_vars = get_config_vars
+
+# The same dictionary is always returned, so we abuse it
+# and modify it in place.
+config_vars = sysconfig.get_config_vars()
+for k, v in list(config_vars.items()):
+    if isinstance(v, str) and ('/db4' in v):
+        j = ' '.join([i for i in v.split() if not i.endswith('/db4')])
+        config_vars[k] = j
+del config_vars
+
+# #############################
 
 
 # do the actual build, install, whatever...
@@ -544,6 +549,8 @@ pybsddb_doc/>`__ --
                     'Programming Language :: Python :: 3.3',
                     'Programming Language :: Python :: 3.4',
                     'Programming Language :: Python :: 3.5',
+                    'Programming Language :: Python :: 3.6',
+                    'Programming Language :: Python :: 3.7',
                     ],
       )
 
